/*
 * alva_api.h - parallel driver for the Alva Braille Terminal serie 3.
 * 
 * Written by Eric Harbers from Alva B.V. - Arnhem _ The Netherlands.
 * Ported to Linux by Jos Lemmens.
 * (C)1998
 */

int BrailleOpen (unsigned char *Controller);
int BrailleProcess (void);
void BrailleClose (void);
unsigned long BrailleRead (unsigned char *Buffer, unsigned long Maxlen);
unsigned long BrailleWrite (unsigned char *Buffer, unsigned long Len);
